==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/core/src/util_tasks/ObjectViewTasks.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_OBJECT_VIEW_TASKS_H_
#define _GB2_OBJECT_VIEW_TASKS_H_

#include <core_api/Task.h>
#include <core_api/ObjectViewModel.h>

#include <QtCore/QPointer>

namespace GB2 {

class Document;

class GB2_COREAPI_EXPORT ObjectViewTask : public Task {
    Q_OBJECT
public:
	enum Type {
		Type_Open,
		Type_Update
	};

	ObjectViewTask(GObjectView* view, const QString& stateName, const QVariantMap& s = QVariantMap());

	ObjectViewTask(GObjectViewFactoryId fid, const QString& viewName = QString(), const QVariantMap& s = QVariantMap());

	virtual void prepare();
	virtual ReportResult report();

	
	virtual void open(){};
	virtual void update(){};
	
	virtual void onDocumentLoaded(Document* d){ Q_UNUSED(d); }

protected:
	Type					taskType;
	QVariantMap				stateData;
	QPointer<GObjectView>	view;
	QString					viewName;
	bool					stateIsIllegal;
	QStringList				objectsNotFound;
	QStringList				documentsNotFound;


	QList<QPointer<Document> > documentsToLoad;
	QList<QPointer<Document> > documentsFailedToLoad;

	QList<QPointer<GObject> > selectedObjects;
};



} // namespace


#endif

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/core/src/util_tasks/ObjectViewTasks.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_OBJECT_VIEW_TASKS_H_
#define _GB2_OBJECT_VIEW_TASKS_H_

#include <core_api/Task.h>
#include <core_api/ObjectViewModel.h>
#include <core_api/GObjectReference.h>

#include <QtCore/QPointer>

namespace GB2 {

class Document;
class GObject;

class GB2_COREAPI_EXPORT ObjectViewTask : public Task {
    Q_OBJECT
public:
	enum Type {
		Type_Open,
		Type_Update
	};

	ObjectViewTask(GObjectView* view, const QString& stateName, const QVariantMap& s = QVariantMap());

	ObjectViewTask(GObjectViewFactoryId fid, const QString& viewName = QString(), const QVariantMap& s = QVariantMap());

	virtual void prepare();
	virtual ReportResult report();

	
	virtual void open(){};
	virtual void update(){};
	
	virtual void onDocumentLoaded(Document* d){ Q_UNUSED(d); }

protected:
	Type					taskType;
	QVariantMap				stateData;
	QPointer<GObjectView>	view;
	QString					viewName;
	bool					stateIsIllegal;
	QStringList				objectsNotFound;
	QStringList				documentsNotFound;


	QList<QPointer<Document> > documentsToLoad;
	QList<QPointer<Document> > documentsFailedToLoad;

	QList<QPointer<GObject> > selectedObjects;
};

class GB2_COREAPI_EXPORT AddToViewTask : public Task {
    Q_OBJECT
public:
    AddToViewTask(GObjectView* v, GObject* obj);
    ReportResult report();

    QPointer<GObjectView>   objView;
    QString                 viewName;
    GObjectReference        objRef;
    QPointer<Document>      objDoc;
    
};

} // namespace


#endif
